@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 from datetime import datetime
 
-from pyinfra.api import StringCommand
+from pyinfra.api import QuoteString, StringCommand
 
 
 def ensure_mode_int(mode):
@@ -64,17 +64,25 @@ def sed_replace(
 
     sed_script = sed_script_formatter.format(line, replace, flags)
 
-    sed_command = StringCommand('sed', '-i.{0}'.format(backup_extension), sed_script, filename)
+    sed_command = StringCommand(
+        'sed', '-i.{0}'.format(backup_extension), sed_script, QuoteString(filename),
+    )
 
     if not backup:  # if we're not backing up, remove the file *if* sed succeeds
         backup_filename = '{0}.{1}'.format(filename, backup_extension)
-        sed_command = StringCommand(sed_command, '&&', 'rm', '-f', backup_filename)
+        sed_command = StringCommand(sed_command, '&&', 'rm', '-f', QuoteString(backup_filename))
 
     return sed_command
 
 
 def chmod(target, mode, recursive=False):
-    return 'chmod {0}{1} {2}'.format(('-R ' if recursive else ''), mode, target)
+    args = ['chmod']
+    if recursive:
+        args.append('-R')
+
+    args.append('{0}'.format(mode))
+
+    return StringCommand(' '.join(args), QuoteString(target))
 
 
 def chown(target, user, group=None, recursive=False, dereference=True):
@@ -91,10 +99,11 @@ def chown(target, user, group=None, recursive=False, dereference=True):
         command = 'chgrp'
         user_group = group
 
-    return '{0}{1}{2} {3} {4}'.format(
-        command,
-        ' -R' if recursive else '',
-        ' -h' if not dereference else '',
-        user_group,
-        target,
-    )
+    args = [command]
+    if recursive:
+        args.append('-R')
+
+    if not dereference:
+        args.append('-h')
+
+    return StringCommand(' '.join(args), user_group, QuoteString(target))
