@@ -9,6 +9,7 @@ import six
 from mock import patch
 
 from pyinfra.api import Config, Inventory
+from pyinfra.api.util import get_kwargs_str
 
 
 def get_command_string(command):
@@ -49,9 +50,6 @@ class FakeState(object):
     def get_temp_filename(*args):
         return '_tempfile_'
 
-    def add_will_add_user(self, username):
-        pass
-
 
 def parse_fact(fact):
     '''
@@ -163,6 +161,23 @@ class FakeHost(object):
     def noop(self, description):
         self.noop_description = description
 
+    def get_fact(self, fact_cls, **kwargs):
+        fact_key = '{0}.{1}'.format(fact_cls.__module__.split('.')[-1], fact_cls.__name__)
+        fact = getattr(self.fact, fact_key, None)
+        if fact is None:
+            raise KeyError('Missing test fact data: {0}'.format(fact_key))
+        if kwargs:
+            return fact.get(get_kwargs_str(kwargs))
+        return fact
+
+    def create_fact(self, fact_cls, data, kwargs):
+        fact = self.get_fact(fact_cls)
+        fact[get_kwargs_str(kwargs)] = data
+
+    def delete_fact(self, fact_cls, kwargs):
+        fact = self.get_fact(fact_cls)
+        fact.pop(get_kwargs_str(kwargs), None)
+
 
 class FakeFile(object):
     _read = False
@@ -239,6 +254,7 @@ class patch_files(object):
             patch('pyinfra.operations.files.os_path.isdir', self.isdir),
             patch('pyinfra.operations.files.walk', self.walk),
             patch('pyinfra.operations.files.makedirs', lambda path: True),
+            patch('pyinfra.api.util.stat', self.stat),
             # Builtin patches
             patch('pyinfra.operations.files.open', self.get_file, create=True),
             patch('pyinfra.operations.server.open', self.get_file, create=True),
@@ -267,6 +283,16 @@ class patch_files(object):
     def isdir(self, dirname, *args):
         return dirname in self.directories
 
+    def stat(self, pathname):
+        if pathname in self.files:
+            mode_int = 33188  # 644 file
+        elif pathname in self.directories:
+            mode_int = 16877  # 755 directory
+        else:
+            raise IOError('No such file or directory: {0}'.format(pathname))
+
+        return os.stat_result((mode_int, 0, 0, 0, 0, 0, 0, 0, 0, 0))
+
     def walk(self, dirname):
         if dirname not in self.directories:
             return
